@@ -28,7 +28,6 @@ class NestedTensors:
 
     def __getitem__(self, key: Any) -> torch.Tensor:
         x = self.data
-
         for step in self._access_keys[key]:
             if isinstance(step, AccessTensorsAttr):
                 x = x.tensors
@@ -113,6 +112,9 @@ class NestedTensors:
     def __neg__(self) -> NestedTensors:
         return self._math_op(None, op=lambda t, _: -t)
 
+    def __pos__(self) -> NestedTensors:
+        return self
+
     def __add__(self, other: Any) -> NestedTensors:
         return self._math_op(other, op=lambda t, o: t + o)
 
@@ -124,6 +126,17 @@ class NestedTensors:
         self.data = res.data
         return self
 
+    def __sub__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: t - o)
+
+    def __rsub__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: o - t)
+
+    def __isub__(self, other: Any) -> NestedTensors:
+        res = self - other
+        self.data = res.data
+        return self
+
     def __mul__(self, other: Any) -> NestedTensors:
         return self._math_op(other, op=lambda t, o: t * o)
 
@@ -135,6 +148,18 @@ class NestedTensors:
         self.data = res.data
         return self
 
+    def __pow__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: t**o)
+
+    def __rpow__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: o**t)
+
+    def __ipow__(self, other: Any) -> NestedTensors:
+        res = self**other
+        self.data = res.data
+        self._update_info()
+        return self
+
     def __matmul__(self, other: Any) -> NestedTensors:
         return self._math_op(other, op=lambda t, o: t @ o)
 
@@ -217,10 +242,37 @@ class NestedTensors:
         return self._math_op(other, op=lambda t, o: t >= o)
 
     def __and__(self, other: Any) -> NestedTensors:
-        return self._math_op(other, op=lambda t, o: t and o)
+        return self._math_op(other, op=lambda t, o: t & o)
+
+    def __rand__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: o & t)
+
+    def __iand__(self, other: Any) -> NestedTensors:
+        res = self & other
+        self.data = res.data
+        return self
 
     def __or__(self, other: Any) -> NestedTensors:
-        return self._math_op(other, op=lambda t, o: t or o)
+        return self._math_op(other, op=lambda t, o: t | o)
+
+    def __ror__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: o | t)
+
+    def __ior__(self, other: Any) -> NestedTensors:
+        res = self | other
+        self.data = res.data
+        return self
+
+    def __xor__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: t ^ o)
+
+    def __rxor__(self, other: Any) -> NestedTensors:
+        return self._math_op(other, op=lambda t, o: o ^ t)
+
+    def __ixor__(self, other: Any) -> NestedTensors:
+        res = self ^ other
+        self.data = res.data
+        return self
 
     def _math_op(self, other: Any, op: Callable[[Any, Any], Any]) -> NestedTensors:
         data = copy.deepcopy(self.data)
